==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SkalaOcenyOsoby.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSkaliOceny;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SkalaOcenyOsoby extends GenericDPSObject {
    /**
     * SKALA_OCENY_OSOBY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SKALA_OCENY_OSOBY.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * SKALA_OCENY_OSOBY.OPIS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String opis;

    /**
     * SKALA_OCENY_OSOBY.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypSkaliOceny typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SKALA_OCENY_OSOBY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SKALA_OCENY_OSOBY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SKALA_OCENY_OSOBY.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SKALA_OCENY_OSOBY.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SKALA_OCENY_OSOBY.OPIS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOpis() {
        return opis;
    }

    /**
     * SKALA_OCENY_OSOBY.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @return SKALA_OCENY_OSOBY.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypSkaliOceny getTyp() {
        return typ;
    }

    /**
     * SKALA_OCENY_OSOBY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypSkaliOceny typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SkalaOcenyOsoby other = (SkalaOcenyOsoby) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opis=").append(opis);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SkalaOcenyOsoby.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.TypSkaliOceny;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SkalaOcenyOsoby extends GenericDPSObject {
    /**
     * SKALA_OCENY_OSOBY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SKALA_OCENY_OSOBY.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * SKALA_OCENY_OSOBY.OPIS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String opis;

    /**
     * SKALA_OCENY_OSOBY.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypSkaliOceny typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SKALA_OCENY_OSOBY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SKALA_OCENY_OSOBY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SKALA_OCENY_OSOBY.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SKALA_OCENY_OSOBY.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SKALA_OCENY_OSOBY.OPIS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOpis() {
        return opis;
    }

    /**
     * SKALA_OCENY_OSOBY.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @return SKALA_OCENY_OSOBY.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypSkaliOceny getTyp() {
        return typ;
    }

    /**
     * SKALA_OCENY_OSOBY.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypSkaliOceny typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SkalaOcenyOsoby other = (SkalaOcenyOsoby) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opis=").append(opis);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
